@@ -16,7 +16,7 @@ __docformat__ = 'restructuredtext'
 # adapted by Francesc Alted 2012-8-18 for bcolz
 
 import sys
-from distutils.version import LooseVersion
+from pkg_resources import parse_version
 
 import numpy
 from numpy.core import numerictypes as _nt
@@ -763,7 +763,8 @@ class DatetimeFormat(object):
 
         # If timezone is default, make it 'naive' or 'UTC' depending on
         # the numpy version
-        if timezone is None and numpy.__version__ >= LooseVersion("1.11"):
+        if (timezone is None and
+            parse_version(numpy.__version__) >= parse_version("1.11")):
             timezone = "naive"
         else:
             timezone = "UTC"
